pub struct SurfaceCodePatch {
pub logical_id: u32,
pub physical_qubits: Vec<u32>,
pub code_distance: u32,
pub x_origin: u32,
pub y_origin: u32,
}Expand description
A surface code patch representing one logical qubit.
Fields
logical_id: u32Logical qubit identifier.
physical_qubits: Vec<u32>Physical qubit indices comprising this patch.
code_distance: u32Code distance for this patch.
x_origin: u32X origin of this patch on the physical qubit grid.
y_origin: u32Y origin of this patch on the physical qubit grid.